==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/tr.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Görüntüleyici",
    "Simple file viewer with slideshow for media" : "Ortam için slayt sunumu içeren basit dosya görüntüleyici",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Sık kullanılanlara eklediğiniz dosyaları doğrudan ön izleme özelliği ile, Nextcloud alanınızdan son tatil fotoğraflarınız, beğendiğiniz film sahneleri, en son romanınız ya da en iyi  GIF görselleri koleksiyonunuz gibi çeşitli içerikleri paylaşabilirsiniz!",
    "Your browser does not support audio." : "Tarayıcınız sesleri desteklemiyor.",
    "Error loading {name}" : "{name} yüklenirken sorun çıktı",
    "You are about to overwrite the original file. Are you sure you want to continue?" : "Özgün dosyanın üzerine yazmak üzeresiniz. İlerlemek istediğinize emin misiniz?",
    "A file with this name already exists. Do you want to overwrite it?" : "Aynı adlı bir dosya zaten var. Üzerine yazılmasını ister misiniz?",
    "Confirm overwrite" : "Üzerine yazmayı onayla",
    "Cancel" : "İptal",
    "Overwrite" : "Üzerine yaz",
    "An error occurred while trying to confirm the file overwrite." : "Dosyanın üzerine yazıldığı doğrulanırken bir sorun çıktı.",
    "Image saved" : "Görsel kaydedildi",
    "Error saving image" : "Görsel kaydedilirken sorun çıktı",
    "Play the live photo" : "Live Photo oynat",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Tarayıcınız görüntüleri desteklemiyor.",
    "This file no longer exists" : "Bu dosya artık yok",
    "There is no plugin available to display this file type" : "Bu dosya türünü görüntüleyebilecek bir eklenti yok",
    "Edit" : "Düzenle",
    "Exit full screen" : "Tam ekrandan çık",
    "Full screen" : "Tam ekran",
    "Open sidebar" : "Kenar çubuğunu aç",
    "Download" : "İndir",
    "Delete" : "Sil",
    "View" : "Görüntüle",
    "Name" : "Ad",
    "Save" : "Kaydet",
    "Save as" : "Farklı kaydet",
    "Back" : "Geri",
    "Loading …" : "Yükleniyor…",
    "Reset" : "Sıfırla",
    "All changes will be lost." : "Tüm değişiklikler kaybolacak.",
    "Are you sure you want to continue?" : "İşlemi sürdürmek istediğinize emin misiniz?",
    "Apply" : "Uygula",
    "Warning" : "Uyarı",
    "Confirm" : "Onayla",
    "Discard changes" : "Değişiklikleri yok say",
    "Undo" : "Geri al",
    "Redo" : "Yinele",
    "Show original image" : "Özgün görseli görüntüle",
    "Zoom in" : "Yakınlaştır",
    "Zoom out" : "Uzaklaştır",
    "Toggle zoom menu" : "Yakınlaştırma menüsünü aç/kapat",
    "Adjust" : "Ayarla",
    "Fine-tune" : "İnce ayar",
    "Filters" : "Süzgeçler",
    "Watermark" : "Filigran",
    "Draw" : "Çizim",
    "Resize" : "Yeniden boyutlandır",
    "Image name" : "Görsel adı",
    "Invalid image." : "Görsel geçersiz.",
    "Error while uploading the image." : "Görsel yüklenirken sorun çıktı.",
    "are not images" : "görsel değil",
    "is not an image" : "bir görsel değil",
    "to be uploaded" : "yüklenecek",
    "Crop" : "Kırp",
    "Original" : "Özgün",
    "Custom" : "Özel",
    "Square" : "Kare",
    "Landscape" : "Yatay",
    "Portrait" : "Dikey",
    "Ellipse" : "Elips",
    "Classic TV" : "Klasik TV",
    "CinemaScope" : "Sinemaskop",
    "Arrow" : "Ok",
    "Blur" : "Bulanıklaştır",
    "Brightness" : "Parlaklık",
    "Contrast" : "Karşıtlık",
    "Un-flip X" : "X ekseninde döndürmeyi geri al",
    "Flip X" : "X ekseninde döndür",
    "Un-flip Y" : "Y ekseninde döndürmeyi geri al",
    "Flip Y" : "Y ekseninde döndür",
    "HSV" : "HSV",
    "Hue" : "Renk tonu",
    "Saturation" : "Doygunluk",
    "Value" : "Değer",
    "Image" : "Görsel",
    "Importing …" : "İçe aktarılıyor…",
    "+ Add image" : "+ Görsel ekle",
    "Upload image" : "Görsel yükle",
    "From gallery" : "Galeriden",
    "Line" : "Çizgi",
    "Pen" : "Kalem",
    "Polygon" : "Çokgen",
    "Sides" : "Yanlar",
    "Rectangle" : "Dikdörtgen",
    "Corner Radius" : "Köşe yarıçapı",
    "Width in pixels" : "Piksel cinsinden genişlik",
    "Height in pixels" : "Piksel cinsinden yüksekilk",
    "Toggle ratio lock" : "En boy oranı kilidini aç/kapat",
    "Reset to original image size" : "Özgün görsel boyutuna sıfırla",
    "Rotate" : "Çevir",
    "Text" : "Metin",
    "Text spacing" : "Metin aralığı",
    "Text alignment" : "Metin hizalaması",
    "Font family" : "Yazı tipi ailesi",
    "Size" : "Boyut",
    "Letter spacing" : "Harf aralığı",
    "Line height" : "Satır yüksekliği",
    "Warmth" : "Sıcaklık",
    "+ Add watermark" : "+ Filigran ekle",
    "+ Add text watermark" : "+ Filigran ekle",
    "Choose watermark type" : "Filigran türünü seçin",
    "Upload watermark" : "Filigran yükle",
    "Add as text" : "Metin olarak ekle",
    "Padding" : "Kenar payı",
    "Paddings" : "Kenar payları",
    "Shadow" : "Gölge",
    "Horizontal" : "Yatay",
    "Vertical" : "Dikey",
    "Opacity" : "Matlık",
    "Transparency" : "Saydamlık",
    "Position" : "Konum",
    "Stroke" : "Kalınlık",
    "Save image as" : "Görseli farklı kaydet",
    "Extension" : "Uzantı",
    "Format" : "Biçim",
    "Name is required." : "Adın yazılması zorunludur.",
    "Quality" : "Kalite",
    "Saved image size (width x height)" : "Kaydedilmiş görsel boyutu (genişlik x yükseklik)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Seçilmiş kırpma alanı uygulanan yeniden boyutlandırma alanından küçük. Bu durum görsel kalitesinin düşmesine neden olabilir.",
    "Actual size (100%)" : "Gerçek boyut (%100)",
    "Fit size" : "Boyutu sığdır",
    "Select image to add …" : "Eklenecek görseli seçin…",
    "Failed to load image." : "Görsel yüklenemedi.",
    "Menu" : "Menü",
    "Width" : "Genişlik",
    "Height" : "Yükseklik",
    "No preview available for this crop item" : "Bu kırpılmış ögenin ön izlemesi yok"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/tr.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Görüntüleyici",
    "Simple file viewer with slideshow for media" : "Ortam için slayt sunumu içeren basit dosya görüntüleyici",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Sık kullanılanlara eklediğiniz dosyaları doğrudan ön izleme özelliği ile, Nextcloud alanınızdan son tatil fotoğraflarınız, beğendiğiniz film sahneleri, en son romanınız ya da en iyi  GIF görselleri koleksiyonunuz gibi çeşitli içerikleri paylaşabilirsiniz!",
    "Your browser does not support audio." : "Tarayıcınız sesleri desteklemiyor.",
    "Error loading {name}" : "{name} yüklenirken sorun çıktı",
    "You are about to overwrite the original file. Are you sure you want to continue?" : "Özgün dosyanın üzerine yazmak üzeresiniz. İlerlemek istediğinize emin misiniz?",
    "A file with this name already exists. Do you want to overwrite it?" : "Aynı adlı bir dosya zaten var. Üzerine yazılmasını ister misiniz?",
    "Confirm overwrite" : "Üzerine yazmayı onayla",
    "Cancel" : "İptal",
    "Overwrite" : "Üzerine yaz",
    "An error occurred while trying to confirm the file overwrite." : "Dosyanın üzerine yazıldığı doğrulanırken bir sorun çıktı.",
    "Image saved" : "Görsel kaydedildi",
    "Error saving image" : "Görsel kaydedilirken sorun çıktı",
    "Play the live photo" : "Live Photo oynat",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Tarayıcınız görüntüleri desteklemiyor.",
    "This file no longer exists" : "Bu dosya artık yok",
    "There is no plugin available to display this file type" : "Bu dosya türünü görüntüleyebilecek bir eklenti yok",
    "Failed to save file before download" : "Dosya indirmeden önce kaydedilemedi",
    "Edit" : "Düzenle",
    "Exit full screen" : "Tam ekrandan çık",
    "Full screen" : "Tam ekran",
    "Open sidebar" : "Kenar çubuğunu aç",
    "Download" : "İndir",
    "Delete" : "Sil",
    "View" : "Görüntüle",
    "Name" : "Ad",
    "Save" : "Kaydet",
    "Save as" : "Farklı kaydet",
    "Back" : "Geri",
    "Loading …" : "Yükleniyor…",
    "Reset" : "Sıfırla",
    "All changes will be lost." : "Tüm değişiklikler kaybolacak.",
    "Are you sure you want to continue?" : "İşlemi sürdürmek istediğinize emin misiniz?",
    "Apply" : "Uygula",
    "Warning" : "Uyarı",
    "Confirm" : "Onayla",
    "Discard changes" : "Değişiklikleri yok say",
    "Undo" : "Geri al",
    "Redo" : "Yinele",
    "Show original image" : "Özgün görseli görüntüle",
    "Zoom in" : "Yakınlaştır",
    "Zoom out" : "Uzaklaştır",
    "Toggle zoom menu" : "Yakınlaştırma menüsünü aç/kapat",
    "Adjust" : "Ayarla",
    "Fine-tune" : "İnce ayar",
    "Filters" : "Süzgeçler",
    "Watermark" : "Filigran",
    "Draw" : "Çizim",
    "Resize" : "Yeniden boyutlandır",
    "Image name" : "Görsel adı",
    "Invalid image." : "Görsel geçersiz.",
    "Error while uploading the image." : "Görsel yüklenirken sorun çıktı.",
    "are not images" : "görsel değil",
    "is not an image" : "bir görsel değil",
    "to be uploaded" : "yüklenecek",
    "Crop" : "Kırp",
    "Original" : "Özgün",
    "Custom" : "Özel",
    "Square" : "Kare",
    "Landscape" : "Yatay",
    "Portrait" : "Dikey",
    "Ellipse" : "Elips",
    "Classic TV" : "Klasik TV",
    "CinemaScope" : "Sinemaskop",
    "Arrow" : "Ok",
    "Blur" : "Bulanıklaştır",
    "Brightness" : "Parlaklık",
    "Contrast" : "Karşıtlık",
    "Un-flip X" : "X ekseninde döndürmeyi geri al",
    "Flip X" : "X ekseninde döndür",
    "Un-flip Y" : "Y ekseninde döndürmeyi geri al",
    "Flip Y" : "Y ekseninde döndür",
    "HSV" : "HSV",
    "Hue" : "Renk tonu",
    "Saturation" : "Doygunluk",
    "Value" : "Değer",
    "Image" : "Görsel",
    "Importing …" : "İçe aktarılıyor…",
    "+ Add image" : "+ Görsel ekle",
    "Upload image" : "Görsel yükle",
    "From gallery" : "Galeriden",
    "Line" : "Çizgi",
    "Pen" : "Kalem",
    "Polygon" : "Çokgen",
    "Sides" : "Yanlar",
    "Rectangle" : "Dikdörtgen",
    "Corner Radius" : "Köşe yarıçapı",
    "Width in pixels" : "Piksel cinsinden genişlik",
    "Height in pixels" : "Piksel cinsinden yüksekilk",
    "Toggle ratio lock" : "En boy oranı kilidini aç/kapat",
    "Reset to original image size" : "Özgün görsel boyutuna sıfırla",
    "Rotate" : "Çevir",
    "Text" : "Yazı",
    "Text spacing" : "Yazı aralığı",
    "Text alignment" : "Yazı hizalaması",
    "Font family" : "Yazı tipi ailesi",
    "Size" : "Boyut",
    "Letter spacing" : "Harf aralığı",
    "Line height" : "Satır yüksekliği",
    "Warmth" : "Sıcaklık",
    "+ Add watermark" : "+ Filigran ekle",
    "+ Add text watermark" : "+ Filigran ekle",
    "Choose watermark type" : "Filigran türünü seçin",
    "Upload watermark" : "Filigran yükle",
    "Add as text" : "Yazı olarak ekle",
    "Padding" : "Kenar payı",
    "Paddings" : "Kenar payları",
    "Shadow" : "Gölge",
    "Horizontal" : "Yatay",
    "Vertical" : "Dikey",
    "Opacity" : "Matlık",
    "Transparency" : "Saydamlık",
    "Position" : "Konum",
    "Stroke" : "Kalınlık",
    "Save image as" : "Görseli farklı kaydet",
    "Extension" : "Uzantı",
    "Format" : "Biçim",
    "Name is required." : "Adın yazılması zorunludur.",
    "Quality" : "Kalite",
    "Saved image size (width x height)" : "Kaydedilmiş görsel boyutu (genişlik x yükseklik)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Seçilmiş kırpma alanı uygulanan yeniden boyutlandırma alanından küçük. Bu durum görsel kalitesinin düşmesine neden olabilir.",
    "Actual size (100%)" : "Gerçek boyut (%100)",
    "Fit size" : "Boyutu sığdır",
    "Select image to add …" : "Eklenecek görseli seçin…",
    "Failed to load image." : "Görsel yüklenemedi.",
    "Menu" : "Menü",
    "Width" : "Genişlik",
    "Height" : "Yükseklik",
    "No preview available for this crop item" : "Bu kırpılmış ögenin ön izlemesi yok"
},
"nplurals=2; plural=(n > 1);");
